@@ -363,7 +363,8 @@ char * escape_filename( char *file_path, char *buffer, int buffer_size )
 
     while( *input )
     {
-        if( iscntrl( *input ) )
+        if( iscntrl( *input ) && 
+          ( (*input) > 0 && (*input) < sizeof(octals) ) )
         {
             *output++ = '\\';
             *output++ = octals[(int)*input][0];
@@ -371,7 +372,7 @@ char * escape_filename( char *file_path, char *buffer, int buffer_size )
             *output++ = octals[(int)*input][2];
 
             input++;
-	    }
+        }
 
         else if ( (*input) == ']' )
         {
