@@ -52,6 +52,7 @@
 #define HOST_CONFIG_KEYWORD_DB_FLAGS        12
 #define HOST_CONFIG_KEYWORD_NOTIFY_EMAIL    13
 #define HOST_CONFIG_KEYWORD_PORT            14
+#define HOST_CONFIG_KEYWORD_CONFIG          15
 
 
 #define HOST_CONFIG_PERMISSIONS		      0600
@@ -85,6 +86,7 @@ typedef struct host_config
     char session_key[HOST_SESSION_KEY_LENGTH];
     char base_db[MAX_HOSTNAME_LENGTH];
     char notify_email[MAX_HOST_NOTIFY_EMAIL_LENGTH];
+    char config[MAX_HOST_BRIEF_CONFIG_LENGTH];
 
     int type;
     int enabled;
