@@ -498,7 +498,7 @@ void process()
         check_for_signals();
         wait_for_data();
 
-#ifdef HAVE_THREADS
+#ifdef WIN32
         cleanup_threads();
 #endif
 
@@ -1183,7 +1183,7 @@ void stop_scan()
 
     /* threads should kill their own scan socket and SSL objects. */
 
-#ifndef HAVE_THREADS
+#ifndef WIN32
     osi_close_socket( scan_data_socket );
     osi_ssl_destroy( &scan_data_ssl );
 #endif
