@@ -318,6 +318,9 @@ OSI_HOST * osi_read_host( const char *name )
 
         osi_strlcpy( host->notify_email, host_brief.notify_email,
                      sizeof( host->notify_email ) );
+
+        osi_strlcpy( host->config, host_brief.config,
+                     sizeof( host->config ) );
             
         host->file_log_enabled  = host_brief.file_log_enabled; 
         host->db_flags          = host_brief.db_flags;
@@ -439,6 +442,9 @@ osi_bool osi_write_host( OSI_HOST *host )
 
     osi_strlcpy( host_brief.notify_email, host->notify_email,
                  sizeof( host_brief.notify_email ) );
+
+    osi_strlcpy( host_brief.config, host->config,
+                 sizeof( host_brief.config ) );
        
     host_brief.file_log_enabled  = host->file_log_enabled; 
     host_brief.db_flags          = host->db_flags;
@@ -770,6 +776,9 @@ osi_bool osi_host_brief_from_host( OSI_HOST *host, OSI_HOST_BRIEF *brief )
     osi_strlcpy( brief->notify_email, host->notify_email,
                  sizeof( brief->notify_email ) );
 
+    osi_strlcpy( brief->config, host->config,
+                 sizeof( brief->config ) );
+
     result = TRUE;
     return result;
 }
