@@ -615,10 +615,15 @@ exit_gracefully:
     return result;
 }   
 
+/* push the config found in the host's baseline database, the one used */
+/* to create that database.  If no baseline database or config name is */
+/* found, we look at the host's config file for the config keyword and */
+/* use that. Otherwise, we fail.                                       */
 
 int osi_host_push_base_db_config( const char *host_name )
 {
     int result = OSI_ERROR_NULL_ARGUMENT;
+    char *config_name = NULL;
 
     OSI_HOST *host;
     OSI_DATABASE_BRIEF db_brief;
@@ -638,19 +643,23 @@ int osi_host_push_base_db_config( const char *host_name )
     result = osi_host_read_database_brief_with_name( &db_brief, host_name,
                                                      host->base_db );
 
-    if( result != OSI_DB_OK )
+    /* try the config in the host.conf file. */
+
+    if ( result != OSI_DB_OK )
     {
-        result = OSI_ERROR_BASE_DB_NOT_FOUND;
-        goto exit_gracefully;
+        config_name = host->config;
+    }
+
+    else
+    {
+        config_name = db_brief.config_name;
     }
 
     /* now get the config name and attempt to push it. */
 
-    result = osi_host_push_config( host_name, db_brief.config_name );
-
-exit_gracefully:
-
+    result = osi_host_push_config( host_name, config_name );
     osi_host_destroy( host );
+
     return result;
 }
 
